# OpenBB Tiingo Provider

This extension integrates the [Tiingo](https://www.tiingo.com/) data provider into the OpenBB Platform.

## Installation

To install the extension:

```bash
pip install openbb-tiingo
```

Documentation available [here](https://docs.openbb.co/platform/development/contributing).
